@@ -1,19 +1,26 @@
 """
-Build API methods
+A jenkins build represents a single execution of a Jenkins Job.
+
+Builds can be thought of as the second level of the jenkins heirarchy
+beneath Jobs. Builds can have state, such as whether they are running or
+not. They can also have outcomes, such as wether they passed or failed.
+
+Build objects can be associated with Results and Artifacts.g
 """
 
 import time
 import pytz
-import datetime
-from jenkinsapi.artifact import Artifact
-from jenkinsapi import config
-from jenkinsapi.jenkinsbase import JenkinsBase
-from jenkinsapi.custom_exceptions import NoResults
-from jenkinsapi.constants import STATUS_SUCCESS
-from jenkinsapi.result_set import ResultSet
-
-from time import sleep
 import logging
+import warnings
+import datetime
+from time import sleep
+from jenkinsapi import config
+from jenkinsapi.artifact import Artifact
+from jenkinsapi.result_set import ResultSet
+from jenkinsapi.jenkinsbase import JenkinsBase
+from jenkinsapi.constants import STATUS_SUCCESS
+from jenkinsapi.custom_exceptions import NoResults
+
 
 log = logging.getLogger(__name__)
 
@@ -56,6 +63,7 @@ class Build(JenkinsBase):
         return getattr(self, '_get_%s_rev' % vcs, lambda: None)()
 
     def _get_svn_rev(self):
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         maxRevision = 0
         for repoPathSet in self._data["changeSet"]["revisions"]:
             maxRevision = max(repoPathSet["revision"], maxRevision)
@@ -74,6 +82,7 @@ class Build(JenkinsBase):
             return revision
 
     def _get_hg_rev(self):
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         return [x['mercurialNodeName'] for x in self._data['actions'] if 'mercurialNodeName' in x][0]
 
     def get_duration(self):
@@ -136,6 +145,7 @@ class Build(JenkinsBase):
         Get the master job name if it exist, None otherwise
         :return: String or None
         """
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         try:
             return self.get_actions()['parameters'][0]['value']
         except KeyError:
@@ -146,6 +156,7 @@ class Build(JenkinsBase):
         Get the master job object if it exist, None otherwise
         :return: Job or None
         """
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         if self.get_master_job_name():
             return self.get_jenkins_obj().get_job(self.get_master_job_name())
         else:
@@ -156,6 +167,7 @@ class Build(JenkinsBase):
         Get the master build number if it exist, None otherwise
         :return: int or None
         """
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         try:
             return int(self.get_actions()['parameters'][1]['value'])
         except KeyError:
@@ -166,6 +178,7 @@ class Build(JenkinsBase):
         Get the master build if it exist, None otherwise
         :return Build or None
         """
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         master_job = self.get_master_job()
         if master_job:
             return master_job.get_build(self.get_master_build_number())
@@ -177,6 +190,7 @@ class Build(JenkinsBase):
         Get the downstream jobs for this build
         :return List of jobs or None
         """
+        warnings.warn("This untested function may soon be removed from Jenkinsapi.")
         downstream_jobs = []
         try:
             for job_name in self.get_downstream_job_names():
